@@ -27,12 +27,10 @@
 #endif
 
 #include <QBrush>
-
-#include <klocale.h>
 #include <QDebug>
 #include <QStandardPaths>
 
-
+#include <KLocalizedString>
 
 KalziumSchemeTypeFactory::KalziumSchemeTypeFactory()
 {
@@ -55,7 +53,7 @@ KalziumSchemeTypeFactory* KalziumSchemeTypeFactory::instance()
 KalziumSchemeType* KalziumSchemeTypeFactory::build(int id) const
 {
     if ((id < 0) || (id >= m_schemes.count())) {
-        return 0;
+        return nullptr;
     }
 
     return m_schemes.at(id);
@@ -69,7 +67,7 @@ KalziumSchemeType* KalziumSchemeTypeFactory::build(const QByteArray& id) const
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
 QStringList KalziumSchemeTypeFactory::schemes() const
@@ -84,7 +82,7 @@ QStringList KalziumSchemeTypeFactory::schemes() const
 
 KalziumSchemeType* KalziumSchemeType::instance()
 {
-    return 0;
+    return nullptr;
 }
 
 KalziumSchemeType::KalziumSchemeType()
